==> rivendell-2.5.0.zip: rivendell-2.5.0/utils/rdgpimon/rdgpimon_nn.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>Database Error</source>
        <translation>Databasefeil</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <comment>Unable to connect to mySQL Server!</comment>
        <translation>Kan ikkje kopla til</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Kan ikkje kopla til</translation>
    </message>
    <message>
        <source>Unable to connect to mySQL Server!</source>
        <translation>Greier ikkje kopla til mySQL-tenaren!</translation>
    </message>
    <message>
        <source>Matrix:</source>
        <translation>Matrise:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <source>RDGpiMon - User:</source>
        <translation type="obsolete">RDGpiMon-brukar:</translation>
    </message>
    <message>
        <source>GPI (Inputs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPO (Outputs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green = ON Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red = OFF Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-2.15.1.zip: rivendell-2.15.1/utils/rdgpimon/rdgpimon_nn.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>Database Error</source>
        <translation>Databasefeil</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <comment>Unable to connect to mySQL Server!</comment>
        <translation>Kan ikkje kopla til</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Kan ikkje kopla til</translation>
    </message>
    <message>
        <source>Unable to connect to mySQL Server!</source>
        <translation>Greier ikkje kopla til mySQL-tenaren!</translation>
    </message>
    <message>
        <source>Matrix:</source>
        <translation>Matrise:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="obsolete">&amp;Lukk</translation>
    </message>
    <message>
        <source>RDGpiMon - User:</source>
        <translation type="obsolete">RDGpiMon-brukar:</translation>
    </message>
    <message>
        <source>GPI (Inputs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GPO (Outputs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green = ON Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red = OFF Cart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Both</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Events Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ON </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OFF</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
